@@ -49,13 +49,6 @@ public:
     return false;
   }
 
-  IntegerVectorList inequalitiesForCone(IntegerVector const &codim1interior, IntegerVector const &newDirection)
-  {
-
-    int i=0;
-
-  }
-
   const char *helpText()
   {
     return "Similar to _fancoarsening, but no fan structure required for algorithm\n";
