@@ -1,3 +1,5 @@
+#define PACKEDNWORDS 4
+
 #include "buchberger.h"
 
 #include <set>
@@ -12,6 +14,7 @@
 
 #include "gebauermoeller.h"
 
+#include "divisionobject.h"
 static Timer buchbergerTimer("Buchberger",10);
 
 
@@ -353,9 +356,20 @@ public:
   }
 };*/
 
-
-void autoReduceNonGB(PolynomialSet *g, TermOrder const &termOrder)
+/**
+ * Let's try to document this:
+ * *g need not be a Groebner basis
+ * but we may still want to do interreductions with respect to some order, not changing the ideal generated by *g.
+ * For this we need a marking. The marking is specified by termOrder.
+ * Actually having termOrder could be an advantage as it can be used for heuristics for in which order
+ * to do the reductions.
+ * At a lower level, in the DivisionObjectFast an integer vector representation of the marking needs to be known.
+ * Either this is computed by the DivsionObject using linear programming, or it is provided via the hint_.
+ */
+void __attribute__ ((noinline)) autoReduceNonGB(PolynomialSet *g, TermOrder const &termOrder, IntegerVector const *hint_=0)
 {
+	IntegerVector hint(g->getRing().getNumberOfVariables());
+	if(hint_)hint=*hint_;
 	g->markAndScale(termOrder);
 //	g->sort(PolynomialCompareMarkedTerms(termOrder));
 	g->sort(PolynomialCompareMarkedTerms(TotalDegreeTieBrokenTermOrder(termOrder)));
@@ -369,8 +383,15 @@ void autoReduceNonGB(PolynomialSet *g, TermOrder const &termOrder)
       g->erase(i);
       Monomial monomial=temp.getMarked().m;
 
-      Polynomial remainder=division(temp,*g,termOrder);
-//      debug<<remainder<<"\n";
+#if 1
+    	  Polynomial remainder=division(temp,*g,termOrder);
+#else
+      DivisionObjectFast<PACKEDNWORDS> DO(*g,&hint,termOrder);
+      DO.reduce(temp);
+      hint=DO.getUsedGrading();
+      Polynomial &remainder=temp;
+#endif
+      //   debug<<remainder<<"\n";
       if(!remainder.isZero())
       {
     	  g->insert(tempIterator,remainder);
@@ -428,7 +449,7 @@ void buchberger2(PolynomialSet *g, TermOrder const &termOrder, bool allowSaturat
 
 
 	g->markAndScale(termOrder);
-	autoReduceNonGB(g,termOrder);
+	autoReduceNonGB(g,termOrder,0);
 	g->markAndScale(termOrder);
 	g->sort(PolynomialCompareMarkedTermsReverse(termOrder));
 //  g->computeInitialSugar();
@@ -463,8 +484,19 @@ void buchberger2(PolynomialSet *g, TermOrder const &termOrder, bool allowSaturat
   int numberOfCriticalPairsConsidered=0;
   int numberOfUsefulCriticalPairs=0;
 
+//  DivisionObjectFast<PACKEDNWORDS> DO(*g,0,termOrder);//,termOrder);
+
+  auto DO=DivisionObjectFactory(g->getRing().getField(),*g,0,termOrder);
+               // DivisionObjectFactory
+  bool DOneedsUpdate=false;
   while(!sPolynomials.isEmpty())
     {
+	  if(DOneedsUpdate)
+	  {
+		  DOneedsUpdate=false;
+		  IntegerVector hint=DO->getUsedGrading();
+		  DO=DivisionObjectFactory(g->getRing().getField(),*g,&hint,termOrder);
+	  }
 	  pair<int,int> ij=sPolynomials.popPair();
 	  Polynomial p=sPolynomial(G[ij.first],G[ij.second]);
 //      if(printDebug)
@@ -483,14 +515,23 @@ void buchberger2(PolynomialSet *g, TermOrder const &termOrder, bool allowSaturat
 
 
 
+/*      {
+    	  auto P=p;
+    	  DivisionObjectNaive DO(*g,termOrder);
+    	  DO.reduce(P);
+    	  debug<<"Naivremainder:"<<P<<"\n";
+      }
+*/
+
+  //    DivisionObjectNaive DO(*g,termOrder);
+      DO->reduce(p);
 
 
-
-
-      p=division(p,*g,termOrder);
+//      p=division(p,*g,termOrder);
       if(allowSaturation)p.saturate();
       if(!p.isZero())
         {
+    	  DOneedsUpdate=true;
     	  p.mark(termOrder);
           p.scaleMarkedCoefficientToOne();
           g->push_back(p);
@@ -558,8 +599,21 @@ void minimize(PolynomialSet *g)
 
 
 
-void autoReduce(PolynomialSet *g, TermOrder const &termOrder)
+void autoReduce(PolynomialSet *g, TermOrder const &termOrder, class WeightRecipe const *recipe)
 {
+	if(0)//This is an easy way to force the usage of priority queues. However, it seems that things could be made more efficient in case of a minimal Groebner basis.
+	{
+		if(recipe)
+		{
+			auto w=recipe->computeWeight(*g);
+			autoReduceNonGB(g,WeightReverseLexicographicTermOrder((w)),&w);
+		}
+		else
+			autoReduceNonGB(g,WeightReverseLexicographicTermOrder(weightVector(*g)));
+
+		return;
+	}
+
 	/**
 	 * TODO: there should be two options : supplying a termorder, or not supplying a termorder. In the latter case this routine should decide if it wants to compute one.
 	 */
