@@ -11,7 +11,7 @@ class GroebnerEngineGfan : public GroebnerEngine
     buchberger(&ret,termOrder,allowSaturation);
     return ret;
   }
-  virtual PolynomialSet autoReduce(bool &success, PolynomialSet const &idealGenerators)
+  virtual PolynomialSet autoReduce(bool &success, PolynomialSet const &idealGenerators, class WeightRecipe const *recipe=0)
   {
     success=true;
     PolynomialSet ret=idealGenerators;
