@@ -364,8 +364,8 @@ std::string SymmetricComplex::toStringJustCones(int dimLow, int dimHigh, bool on
   return ret.str();
 }
 
-
-ZVector SymmetricComplex::fvector(bool boundedPart)const
+// Only set one flag in the argument list. FIRST ENTRY IS HOMOGENISING COORDINATE
+ZVector SymmetricComplex::fvector(bool boundedPart, bool infinityPart)const
 {
   int min=getMinDim();
   int dimHigh=getMaxDim();
@@ -374,14 +374,23 @@ ZVector SymmetricComplex::fvector(bool boundedPart)const
 
   for(ConeContainer::const_iterator i=cones.begin();i!=cones.end();i++)
     {
-      bool doAdd=!boundedPart;
+      bool doAdd=true;
       if(boundedPart)
         {
+    	  doAdd=!boundedPart;
           bool isBounded=true;
           for(unsigned j=0;j<i->indices.size();j++)
             if(vertices[i->indices[j]][0].sign()==0)isBounded=false;
           doAdd=isBounded;
         }
+      else
+    	  if(infinityPart)
+    	  {
+    		  bool isAtInfinity=true;
+    		  for(unsigned j=0;j<i->indices.size();j++)
+    			  if(vertices[i->indices[j]][0].sign()!=0)isAtInfinity=false;
+    		  doAdd=isAtInfinity;
+    	  }
       if(doAdd)
         ret[i->dimension-min]+=Integer(sym.orbitSize(i->sortKey));
     }
