@@ -452,12 +452,18 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 			//columns have been added to configuration this->subconfigurationIndex
 			//for that reason we need to introduce new circuits. Old circuits are preserved.
 			//chioices are "relative" so no update is needed.
-
+//			std::cerr<<A.toString();
 			choices=parent.choices;
-			int numberToDrop=(subconfigurationIndex!=0) ? numberToDrop=k+1 : 0;
-
-			choices[subconfigurationIndex-1].first-=numberToDrop;
-			choices[subconfigurationIndex-1].second-=numberToDrop;
+			int numberToDrop=(subconfigurationIndex!=0) ? k+1 : 0;
+//			std::cerr<<"subconfigurationindex"<<subconfigurationIndex<<"\n";
+//			std::cerr<<"numbertodrop"<<numberToDrop<<"\n";
+//			for(auto &a:choices)std::cerr<<"("<<a.first<<","<<a.second<<")\n";
+			if(subconfigurationIndex)
+			{
+				choices[subconfigurationIndex-1].first-=numberToDrop;
+				choices[subconfigurationIndex-1].second-=numberToDrop;
+			}
+//			for(auto &a:choices)std::cerr<<"("<<a.first<<","<<a.second<<")\n";
 
 			denominator=parent.denominator;
 			int offsetOld=0;
@@ -522,7 +528,13 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 			for(int a=0;a<k;a++)
 			for(int i=0;i<k+Flags::computeDotProductInMatrix;i++)
 			{
+//				std::cerr<<"a:"<<a<<A.getWidth()<<"\n";
+//				std::cerr<<offsets[a]+choices[a].first<<"\n";
+//				std::cerr<<offsets[a]<<choices[a].first<<"\n";
 				A[i][offsets[a]+choices[a].first]=0;
+//				std::cerr<<offsets[a]+choices[a].second<<"\n";
+//				std::cerr<<offsets[a]<<choices[a].second<<"\n";
+//				std::cerr<<"a:"<<a<<A.getWidth()<<"\n";
 				A[i][offsets[a]+choices[a].second]=0;
 			}
 		}
@@ -602,10 +614,16 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 			useFirstChanged=false;
 			useSecondChanged=false;
 			int onlyK=-1;
-#if 1
+#if 0
 			if(eliminatedK!=-1)
+			{
+				std::cerr<<"EK"<<eliminatedK<<"\n";
+				std::cerr<<"choices[eliminatedK].first"<<choices[eliminatedK].first<<"\n";
+				std::cerr<<"eliminatedKOffset"<<eliminatedKOffset<<"\n";
+				std::cerr<<"target.size()"<<target.size()<<"\n";
 				if(target[choices[eliminatedK].first+eliminatedKOffset]==target[choices[eliminatedK].second+eliminatedKOffset])
 					onlyK=eliminatedK;
+			}
 #endif
 
 			inequalityTable.compareInequalities(result,target,onlyK);
@@ -751,6 +769,10 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 			  Vector<mvtyp> degrees;
 			  bool isFiniteIndex(int level, int index)
 			  {
+//				  std::cerr<<"level"<<level<<"index"<<index<<"tuple.size()"<<tuple.size()<<"\n";
+				  if(level>=tuple.size()) //we are past the process of regeneration
+					  return true;
+//				  std::cerr<<"Index"<<index<<"height"<<tuple[0].getHeight()<<"\n";
 				  return index>=tuple[0].getHeight()+1;
 			  }
 
@@ -766,7 +788,7 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 				  }
 				  return ret;
 				}
-			  Data(std::vector<Matrix<mvtyp> > const &tuple_):tuple(tuple_)
+			  Data(std::vector<Matrix<mvtyp> > const &tuple_, Vector<mvtyp> const *target=0):tuple(tuple_)
 			  {
 				  int n=tuple[0].getHeight();
 
@@ -786,9 +808,13 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 
 				  for(int i=0;i<tuple.size();i++)
 					  degrees.push_back(degree(tuple[i]));
+				  if(target)
+					  degrees.push_back(1);
 
 				  for(int i=0;i<tuple.size();i++)
 					  tuples.push_back(produceIthTuple(i));
+				  if(target)
+					  tuples.push_back(tuple);
 
 				  for(int i=0;i<tuple.size();i++)
 				  {
@@ -802,6 +828,8 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 					  }
 					  targets.push_back(targ);
 				  }
+				  if(target)
+					  targets.push_back(*target);
 			  };
 
 			  std::vector<std::pair<int,int> > firstIntersection()
@@ -842,12 +870,14 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 		bool isLevelLeaf;
 		bool isSolutionVertex;
 		std::vector<bool> isLevelLeafStack;
-		TropicalRegenerationTraverser(std::vector<Matrix<mvtyp> > const &tuple_):
-			fullData(tuple_),counter(0),depth(0)
+		TropicalRegenerationTraverser(std::vector<Matrix<mvtyp> > const &tuple_, Vector<mvtyp> const *target=0):
+			fullData(tuple_,target),counter(0),depth(0)
 		{
 			assert(tuple_.size());
 			for(int i=0;i<tuple_.size();i++)
 				traversers.push_back(MySingleTropicalHomotopyTraverser(fullData.tuples[i],cayleyConfigurationWidth(fullData.tuples[i]),fullData.firstIntersection(),fullData.targets[i],i));
+			if(target)
+				traversers.push_back(MySingleTropicalHomotopyTraverser(fullData.tuples[tuple_.size()],cayleyConfigurationWidth(fullData.tuples[tuple_.size()]),fullData.firstIntersection(),*target,tuple_.size()/*Needed to figure out how to construct solution from earlier solution.*/));
 			traversers[0].constructInequalityTableInitially(fullData.degrees[0]);
 			level=0;
 		}
@@ -859,11 +889,13 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 			isSolutionVertex=false;
 			deadEnd=false;
 			isLevelLeaf=traversers[level].findOutgoingAndProcess(false);
+//			std::cerr<<"isLevelLeaf_"<<isLevelLeaf<<"\n";
 			if(isLevelLeaf)
 			{//leaf
 				bool isFinite=fullData.isFiniteIndex(level,traversers[level].choices[level].first)&&fullData.isFiniteIndex(level,traversers[level].choices[level].second);
 				deadEnd=!isFinite;
-				if(isFinite && (level==fullData.tuple.size()-1))
+//std::cerr<<"ISFINITE"<<isFinite<<"\n";
+				if(isFinite && (level==fullData.tuples.size()-1))
 				{
 					isSolutionVertex=true;
 					if(doProcess){process();}
@@ -874,7 +906,10 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 		}
 		int numberOfChildren()
 		{
-			if(isLevelLeaf&&(level==fullData.tuple.size()-1))return 0;
+//			std::cerr<<"level"<<level<<"\n";
+//			std::cerr<<"isLevelLeaf"<<isLevelLeaf<<"\n";
+//			std::cerr<<"fullData.tuples.size()"<<fullData.tuples.size()<<"\n";
+			if(isLevelLeaf&&(level==fullData.tuples.size()-1))return 0;
 			if(!isLevelLeaf)
 				return traversers[level].numberOfChildren();
 			else
@@ -921,14 +956,13 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 	class SpecializedRTraverser: public Traverser
 	{
 	public:
-		typedef TropicalRegenerationTraverser<mvtyp,mvtypDouble,mvtypDivisor> MyTropicalRegenerationTraverser;
-		MyTropicalRegenerationTraverser T;
-		mvtypDouble mixedVolume;
+//		typedef TropicalRegenerationTraverser<mvtyp,mvtypDouble,mvtypDivisor> MyTropicalRegenerationTraverser;
+//		MyTropicalRegenerationTraverser T;
+		 TropicalRegenerationTraverser<mvtyp,mvtypDouble,mvtypDivisor>  T;
 		int numberOfExpensiveSteps;
-		SpecializedRTraverser(std::vector<Matrix<mvtyp> > const &tuple_):
-			 mixedVolume(),
+		SpecializedRTraverser(std::vector<Matrix<mvtyp> > const &tuple_, Vector<mvtyp> const *target=0):
 			 numberOfExpensiveSteps(0),
-			 T(tuple_) //Constructor my throw if input is too big.
+			 T(tuple_,target) //Constructor my throw if input is too big.
 		{
 			numberOfExpensiveSteps++;
 			T.findOutgoingAndProcess(false);
@@ -938,6 +972,7 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 			if(!aborting)
 			{
 				try{
+//					std::cerr<<"N children"<<T.numberOfChildren()<<"\n";
 					return T.numberOfChildren();
 				}
 				catch(...){abort();}
@@ -971,13 +1006,17 @@ template<class mvtyp, class mvtypDouble, class mvtypDivisor>
 		  }
 	  }
 
+	  virtual void process()
+		{
+		}
+
 	  void  collectInfo( void )
 	  {
 		  if(!aborting)
 		  {
 			  try{
 				  if(T.isSolutionVertex)
-					  mixedVolume.addWithOverflowCheck(T.traversers[T.level].inequalityTable.getVolume().extend());
+					  process();
 			  }
 			  catch(...){abort();}
 		  }
