@@ -27,12 +27,12 @@ class GroebnerEngine
   /**
      
    */
-  virtual PolynomialSet autoReduce(bool &success, PolynomialSet const &idealGenerators)=0;  
+  virtual PolynomialSet autoReduce(bool &success, PolynomialSet const &idealGenerators, class WeightRecipe const *recipe=0)=0;
 };
 
 
 PolynomialSet GE_groebnerBasis(PolynomialSet const &idealGenerators, TermOrder const &termOrder, bool autoreduce, bool allowSaturation);
-PolynomialSet GE_autoReduce(PolynomialSet const &idealGenerators);  
+PolynomialSet GE_autoReduce(PolynomialSet const &idealGenerators, class WeightRecipe const *recipe=0);
 bool GE_SetEngine(const char *name);
 
 
