@@ -245,6 +245,8 @@ public:
    order to trace the path back the unique point of the ray from which
    the ridge was reached is stored in parentRay.
  */
+
+namespace symmetricTraversalNamespace{
 struct pathStepRidge
 {
   IntegerVector parentRidge;
@@ -257,7 +259,9 @@ struct pathStepFacet
   IntegerVectorList ridges;
   IntegerVectorList ridgesRayUniqueVector;//stores the ray of the link that we came from
 };
+};
 
+using namespace symmetricTraversalNamespace;
 /**
   We need to simulate two mutually recursive functions. An actual
   implementation of these two functions would probably not work since
