@@ -24,6 +24,11 @@ static Timer tropicalPrincipalIntersectionTimer("Tropical principal intersection
 //////////////////////////////////////////////////////////////////////////
 //Using stable intersections and rational functions
 
+/**
+ * This method returns the result of moving the indeterminates marked in isGenereric to the coefficient
+ * field (as parameters of rational functions) in g. If noHomog=false, in addition the result is homogenised
+ * before being returned.
+ */
 PolynomialSet buildH(PolynomialSet const &g, IntegerVector const &isGeneric, bool noHomog=false)
 {
 	int sum=isGeneric.sum();
@@ -62,17 +67,26 @@ PolynomialSet buildH(PolynomialSet const &g, IntegerVector const &isGeneric, boo
 	//We must make sure that the ideal remains homogeneous when turning some variables into parameters.
 }
 
+
+/**
+ * This function takes a vector v1 and pads with zeros, according to where isGeneric[] is true.
+ * The output is a vector of the same size as isGeneric.
+ */
 IntegerVector reconstruct(IntegerVector const &v1, IntegerVector const &isGeneric)
 {
 	int n=isGeneric.size();
 	IntegerVector v2(n);
 	int I=0;
-	for(int i=0;i<n;i++)if(!isGeneric[i])v2[i]=v1[I++];
+	for(int i=0;i<n;i++)if(!isGeneric[i])v2[i]=v1[I++]/*-v1[v1.size()-1]*/;
+
 	return v2;
 }
 
 /**
+ * The groebnerBasis is not assumed to be homogeneous. In fact dehomogenisation has (typically?) happened here.
  *
+ * This first part of the code sets up the isGeneric vector to describe which variables must be made generic
+ * to let the variety have dimension 1.
  */
 IntegerVector nonTrivialTropismInner(PolynomialSet const &groebnerBasis)
 {
@@ -156,6 +170,10 @@ IntegerVector nonTrivialTropismInner(PolynomialSet const &groebnerBasis)
 	return IntegerVector(n);
 }
 
+/**
+ * The groebnerBasis is not required to be homogeneous. However, in case there is a homogeneity space (of the generators),
+ * it will be discovered, and the computation done in lower dimension.
+ */
 IntegerVector nonTrivialTropism(PolynomialSet const &groebnerBasis)
 {
 	list<int> toKeep=groebnerBasis.multiDeHomogenizationToKeep();
@@ -347,7 +365,11 @@ static PolynomialSet checkList(IntegerVectorList const &l, PolynomialSet const &
 }
 
 
-
+/**
+ * This routine will produce a list of vectors which when combined with infinitesimal coefficients will give a
+ * non-zero(?) vector in the tropical variety of groebnerBasis.
+ * The input groebnerBasis is not required to be homogeneous.
+ */
 IntegerVectorList perturbedRelativeInteriorTropism(PolynomialSet const &groebnerBasis)
 {
 	int n=groebnerBasis.getRing().getNumberOfVariables();
@@ -403,7 +425,9 @@ if homog>0
 	*/
 }
 
-
+/*
+ * The ideal generated by groebnerBasis must be homogeneous.
+ */
 PolynomialSet guessInitialIdealWithoutMonomial(PolynomialSet const &groebnerBasis, PolynomialSet *fullNeighbourBasis, bool onlyCheckRays) //ideal must be homogeneous
   // fullNeighbourBasis is set to a Groebner basis of the full ideal. The returned basis and fullNeighbourBasis have at least one termorder in common
 {
